<?php

use Bitrix\Rest\Configuration\Helper;
use Bitrix\Rest\Configuration\Structure;
use Bitrix\Main\EventManager;
use Bitrix\Main\Loader;
use Bitrix\Main\Application;

if (!defined("B_PROLOG_INCLUDED") || B_PROLOG_INCLUDED !== true):
	require_once($_SERVER["DOCUMENT_ROOT"] . "/bitrix/modules/main/include/prolog_before.php");
	$request = Application::getInstance()->getContext()->getRequest();
	$manifest = $request->getQuery("manifest");
	if ($manifest && Loader::includeModule('rest'))
	{
		$postfix = 'export' . $manifest;
		$context = Helper::getInstance()->getContextUser($postfix);
		$structure = new Structure($context);

		$files = [];
		$fileList = $structure->getFileList();
		$archiveFolder = $structure->getFolder();
		if (is_array($fileList))
		{
			$folderName = Helper::STRUCTURE_FILES_NAME;
			if (!file_exists($archiveFolder . $folderName))
			{
				mkdir($archiveFolder . $folderName, 0755, true);
			}

			foreach ($fileList as $file)
			{
				$id = (int) $file['ID'];
				$fileData = \CFile::GetByID($id)->fetch();
				if ($fileData)
				{
					$path = \CFile::GetPath($id);
					$files[$id] = array_merge(
						[
							'NAME' => $fileData['ORIGINAL_NAME'],
						],
						$file
					);

					if (
						!file_exists($_SERVER['DOCUMENT_ROOT'] . $path)
						|| !copy($_SERVER['DOCUMENT_ROOT'] . $path, "{$archiveFolder}{$folderName}/{$id}")
					)
					{
						echo 'error file {$id}';
					}
				}
			}
		}

		if ($files)
		{
			$structure->saveContent(false, Helper::STRUCTURE_FILES_NAME, $files);
		}
		$folderFiles = $structure->getConfigurationFileList();
		foreach ($folderFiles as $file)
		{
			$id = $file['ID'];
			$name = $file['NAME'];

			$fileData = \CFile::GetByID($id)->fetch();
			if ($fileData)
			{
				$path = \CFile::GetPath($id);
				$concurrentDirectory = $archiveFolder . str_replace($fileData['ORIGINAL_NAME'], '', $name);
				if (
					!file_exists($concurrentDirectory) && !mkdir($concurrentDirectory, 0777, true)
					&& !is_dir(
						$concurrentDirectory
					)
				)
				{
					echo 'Directory "%s" was not created';
				}
				if (
					!file_exists($_SERVER['DOCUMENT_ROOT'] . $path)
					|| !copy($_SERVER['DOCUMENT_ROOT'] . $path, $archiveFolder . $name)
				)
				{
					echo 'error file {$id}';
				}
			}
		}

		echo '    ,        zip  (     manifest.json):';
		echo '<textarea style="width: 100%;height: 100px;">' . $archiveFolder . '</textarea>';
	}

	require_once($_SERVER["DOCUMENT_ROOT"] . "/bitrix/modules/main/include/epilog_after.php");
	die;
endif;

$eventManager = EventManager::getInstance();
$eventManager->addEventHandler(
	'main',
	'OnEndBufferContent',
	[
		'ModZipContent',
		'onEndBuffer',
	]
);

if (!class_exists('ModZipContent'))
{
	class ModZipContent
	{
		private static $city = [];

		public static function onEndBuffer(&$content)
		{
			if (strpos($_SERVER['REQUEST_URI'], '/marketplace/configuration/export_') !== false)
			{

				$matches = [];
				preg_match(
					'/(\/marketplace\/configuration\/export_)([a-zA-Z0-9_]+)\\//',
					$_SERVER['REQUEST_URI'],
					$matches
				);
				if ($matches[2])
				{
					$path = \getLocalPath('php_interface/' . pathinfo(__FILE__, PATHINFO_BASENAME))
							. '?manifest='
							. $matches[2];

					$replace = [
						"/<div class=\"rest-configuration-info\"/",
					];
					$place = [
						'<a target="_blank" class="ui-btn ui-btn-lg ui-btn-primary start-btn" href="'
						. $path
						. '"> (  )</a>$0',
					];

					$content = preg_replace($replace, $place, $content);
				}

			}
		}
	}
}